"use client";
import React, { useEffect, useState } from "react";
import { usePathname } from "next/navigation"; // Corrected import
import Image from "next/image";
import Link from "next/link";
import { BurgerIcon } from "@/icons";

function Navbar() {
  const [isProjectsOpen, setIsProjectsOpen] = useState(false);
  const pathname = usePathname();

  const isActive = (path: string) => pathname === path;
  const [isScrolled, setIsScrolled] = useState(false);
  const [isOpen, SetIsOpen] = useState(false);
  const toggleMenu = () => {
    SetIsOpen((prev) => !prev);
  };

  // Detect Scroll
  useEffect(() => {
    const handleScroll = () => {
      setIsScrolled(window.scrollY > 10);
    };

    window.addEventListener("scroll", handleScroll);
    return () => window.removeEventListener("scroll", handleScroll);
  }, []);

  return (
    <div className="bg-white">
      <div className="flex justify-between items-center px-10 hidden md:flex lg:flex">
        {/* Logo */}
        <div className="flex justify-center items-center">
          <Image src="/logo.png" alt="logo" height={350} width={360} />
        </div>

        {/* Navbar Links */}
        <div className="flex gap-10 text-[20px] text-[#4F4F4F] font-openSans font-[600] relative">
          <Link
            href="/"
            className={isActive("/") ? "border-b-2 border-black" : ""}
          >
            Home
          </Link>

          {/* Projects Dropdown */}
          <div
            className="relative"
            onMouseEnter={() => setIsProjectsOpen(true)}
            onMouseLeave={() => setIsProjectsOpen(false)}
          >
            <button
              className={`focus:outline-none ${
                pathname.startsWith("/projects")
                  ? "border-b-2 border-black"
                  : ""
              }`}
            >
              Projects
            </button>
            {isProjectsOpen && (
              <div className="absolute left-0 top-full w-56 bg-white shadow-lg border rounded-md z-50">
                <Link
                  href="/projects/web-dev"
                  className={`block px-4 py-2 hover:bg-gray-200 ${
                    isActive("/projects/web-dev") ? "font-bold" : ""
                  }`}
                >
                  Web Development
                </Link>
                <Link
                  href="/projects/restaurant-solutions"
                  className={`block px-4 py-2 hover:bg-gray-200 ${
                    isActive("/projects/restaurant-solutions")
                      ? "font-bold"
                      : ""
                  }`}
                >
                  Restaurant Solutions
                </Link>
              </div>
            )}
          </div>

          <Link
            href="/services"
            className={isActive("/services") ? "border-b-2 border-black" : ""}
          >
            Services
          </Link>
          <Link
            href="/aboutus"
            className={isActive("/aboutus") ? "border-b-2 border-black" : ""}
          >
            About
          </Link>
          <Link
            href="/contact"
            className={isActive("/contact") ? "border-b-2 border-black" : ""}
          >
            Contact Us
          </Link>
        </div>

        {/* Talk to Us Button */}
        <div className="cursor-pointer">
          <div className="bg-[#398D9C] text-white font-[700] text-[20px] w-[260px] flex justify-center pt-2 pb-2 font-openSans">
            Talk With Us
          </div>
        </div>
      </div>

      <div>
        {/* Navbar */}

        <div className="w-[100%] md:hidden lg:hidden fixed top-0 left-0 w-full z-50 transition-all duration-300 flex justify-between items-center p-2  bg-[white] border-b-2 border-b-black">
          <Image
            src="/logo.png"
            alt="logo"
            height={280}
            width={180}
            className=""
          />
          <button onClick={toggleMenu}>
            <BurgerIcon />
          </button>
        </div>
        {isOpen && (
          <div className="relative">
            {/* Dropdown */}
            <div
              className="md:hidden lg:hidden fixed top-[80px] rounded-l-[15px] rounded-br-[15px] bg-[black] px-5 py-1 shadow-lg transition-all duration-300 right-0 z-50 
before:absolute before:-top-[15px] before:right-0 before:h-0 before:w-0 
before:border-b-[15px] before:border-l-[18px] before:border-r-[12px] 
before:border-b-[black] before:border-l-transparent before:border-r-transparent 
before:border-t-transparent before:content-['']"
            >
              <a
                href="/"
                className="font-sans block w-[300px] border-b border-white py-3 text-center text-lg font-medium text-white last:border-none"
              >
                Home
              </a>

              <a
                href="/projects/web-dev"
                className="font-sans block w-[300px] border-b border-white py-3 text-center text-lg font-medium text-white last:border-none"
              >
                Web Development
              </a>
              <a
                href="/services"
                className="font-sans block w-[300px] border-b border-white py-3 text-center text-lg font-medium text-white last:border-none"
              >
                Services
              </a>
              <a
                href="/aboutus"
                className="font-sans block w-[300px] border-b border-white py-3 text-center text-lg font-medium text-white last:border-none"
              >
                About
              </a>
              <a
                href="/contact"
                className="font-sans block w-[300px] border-b border-white py-3 text-center text-lg font-medium text-white last:border-none"
              >
                Contactus
              </a>
            </div>
          </div>
        )}
      </div>

      {/* Bottom Bar */}
      <div className="w-full bg-black flex justify-between text-white text-[12px] pl-10 pr-10 pt-2 pb-2 hidden md:flex lg:flex">
        <p>What’s new in the latest release of Tevozo?</p>
        <Link href="/projects/restaurant-solutions">
          <p>Read Now</p>
        </Link>
      </div>
    </div>
  );
}

export default Navbar;
